function CL = bandpacking(d)
  % CL = bandbacking(d)
  % Compute the successors of the proper Descartes quadruple
  %   ((4,1+4i), (1,1+2i), (1,1), (0,-1))
  % with curvatures at most d and centers in (0,1)^2.
	 
  CL = [4; 1+4i; 1;1+2i; 1; 1; 0; -1];

  k = 0;
  while k < size(CL,2)
    k = k + 1;

    C0 = CL(1:2,k);
    C1 = CL(3:4,k);
    C2 = CL(5:6,k);
    C3 = CL(7:8,k);

    for j = 1:3
      C4 = 2*(C0+C2+C3)-C1;
      if C4(1) <= d && imag(C4(2)) <= C4(1)
	CL(:,end+1) = [C4;C0;C2;C3];
      end
      [C1,C2,C3] = deal(C2,C3,C1);
    end

  end

  % sort by curvature

  CL = unique(CL','rows')';

end
